@@ -78,6 +78,16 @@ class Parser(object):
     _shebangKeywords = []
     _keywords = []
     
+    @classmethod
+    def getParserName(cls) :
+        name = cls.__name__
+        if name.endswith('Parser') and len(name)>=6:
+            name = name[:-6].lower()
+        return name
+
+    @classmethod
+    def disambiguate(cls, text) :
+        return cls.getParserName()
     
     def parseLine(self, line, previousState=0):
         """ parseLine(line, previousState=0)
